@@ -136,19 +136,22 @@ Constants only relevant to SNMP. These are the tag values used by SNMP in
 the C<ASN_APPLICATION> namespace and have the exact numerical value as in
 BER/RFC 2578.
 
-      SNMP_IPADDRESS SNMP_COUNTER32 SNMP_UNSIGNED32 SNMP_TIMETICKS SNMP_OPAQUE SNMP_COUNTER64
+      SNMP_IPADDRESS SNMP_COUNTER32 SNMP_UNSIGNED32 SNMP_GAUGE32
+      SNMP_TIMETICKS SNMP_OPAQUE SNMP_COUNTER64
 
 =item C<:decode>
 
 C<ber_decode> and the match helper functions:
 
-      ber_decode ber_is ber_is_seq ber_is_int ber_is_oid
+      ber_decode ber-decode_prefix
+      ber_is ber_is_seq ber_is_int ber_is_oid
 
 =item C<:encode>
 
 C<ber_encode> and the construction helper functions:
 
-      ber_encode ber_int
+      ber_encode
+      ber_int
 
 =back
 
@@ -254,7 +257,7 @@ See the SYNOPSIS for an example of such an encoded tuple representation.
 
 =over
 
-=item $tuple = ber_decoded $bindata[, $profile]
+=item $tuple = ber_decode $bindata[, $profile]
 
 Decodes binary BER data in C<$bindata> and returns the resulting BER
 tuple. Croaks on any decoding error, so the returned C<$tuple> is always
@@ -277,6 +280,18 @@ Example: as above, but use the provided SNMP profile.
 
    $tuple = ber_encode $data, $Convert::BER::XS::SNMP_PROFILE;
 
+=item ($tuple, $bytes) = ber_decode_prefix $bindata[, $profile]
+
+Works like C<ber_decode>, except it doesn't croak when there is data after
+the BER data, but instead returns the decoded value and the number of
+bytes it decoded.
+
+This is useful when you have BER data at the start of a buffer and other
+data after, and you need to find the length.
+
+Also, since BER is self-delimited, this can be used to decode multiple BER
+values joined together.
+
 =item $bindata = ber_encode $tuple[, $profile]
 
 Encodes the BER tuple into a BER/DER data structure. AS with
@@ -395,7 +410,7 @@ use Exporter qw(import);
 our $VERSION;
 
 BEGIN {
-   $VERSION = 0.9;
+   $VERSION = '1.0';
    XSLoader::load __PACKAGE__, $VERSION;
 }
 
@@ -419,10 +434,11 @@ our %EXPORT_TAGS = (
       BER_TYPE_IPADDRESS BER_TYPE_CROAK
    )],
    const_snmp => [qw(
-      SNMP_IPADDRESS SNMP_COUNTER32 SNMP_UNSIGNED32 SNMP_TIMETICKS SNMP_OPAQUE SNMP_COUNTER64
+      SNMP_IPADDRESS SNMP_COUNTER32 SNMP_GAUGE32 SNMP_UNSIGNED32
+      SNMP_TIMETICKS SNMP_OPAQUE SNMP_COUNTER64
    )],
    decode => [qw(
-      ber_decode
+      ber_decode ber_decode_prefix
       ber_is ber_is_seq ber_is_int ber_is_oid
    )],
    encode => [qw(
@@ -636,6 +652,9 @@ join them for convenience.
 
 REAL values are not supported and will currently croak.
 
+The encoder and decoder tend to accept more formats than should be
+strictly supported.
+
 This module has undergone little to no testing so far.
 
 =head2 ITHREADS SUPPORT
